Class: CMDx::Coercions::Failure

Inherits:
Data
  • Object
show all
Defined in:
lib/cmdx/coercions.rb

Overview

Sentinel returned by a coercion when the value can’t be converted. Runtime records the message as a validation error against the attribute.

Instance Attribute Summary collapse

Instance Attribute Details

#messageObject (readonly)

Returns the value of attribute message

Returns:

  • (Object)

    the current value of message



13
14
15
# File 'lib/cmdx/coercions.rb', line 13

def message
  @message
end