Class: CMDx::Coercions::Failure
- Inherits:
-
Data
- Object
- Data
- CMDx::Coercions::Failure
- Defined in:
- lib/cmdx/coercions.rb
Overview
Sentinel returned by a coercion when the value can’t be converted. Runtime records the message as a validation error against the attribute.
Instance Attribute Summary collapse
-
#message ⇒ Object
readonly
Returns the value of attribute message.
Instance Attribute Details
#message ⇒ Object (readonly)
Returns the value of attribute message
13 14 15 |
# File 'lib/cmdx/coercions.rb', line 13 def @message end |